@@ -33,19 +33,7 @@
 #include <gphoto2/gphoto2-library.h>
 #include <gphoto2/gphoto2-result.h>
 
-#ifdef ENABLE_NLS
-#  include <libintl.h>
-#  undef _
-#  define _(String) dgettext (PACKAGE, String)
-#  ifdef gettext_noop
-#    define N_(String) gettext_noop (String)
-#  else
-#    define N_(String) (String)
-#  endif
-#else
-#  define _(String) (String)
-#  define N_(String) (String)
-#endif
+#include "libgphoto2/i18n.h"
 
 #define GP_MODULE
 
@@ -233,8 +221,8 @@ get_file_func (CameraFilesystem *fs, const char *folder, const char *filename,
 			result[19] = 0x00;
 
 			memmove(&result[20],
-			       &result[app1len + 4],
-			       (unsigned int)(size - app1len - 4));
+				&result[app1len + 4],
+				(unsigned int)(size - app1len - 4));
 
 			size = size - app1len + 20 + 4;
 
@@ -439,8 +427,8 @@ get_file_func (CameraFilesystem *fs, const char *folder, const char *filename,
 		result[19] = 0x00;
 
 		memmove(&result[20],
-		       &result[app1len + 4],
-		       (unsigned int)(size - app1len - 4));
+			&result[app1len + 4],
+			(unsigned int)(size - app1len - 4));
 
 		size = size - app1len + 24;
 
@@ -664,10 +652,10 @@ camera_init (Camera *camera, GPContext *context)
 
 	GP_DEBUG(" * camera_init()");
 
-        /* First, set up all the function pointers */
-        camera->functions->exit                 = camera_exit;
-        camera->functions->summary              = camera_summary;
-        camera->functions->about                = camera_about;
+	/* First, set up all the function pointers */
+	camera->functions->exit = camera_exit;
+	camera->functions->summary = camera_summary;
+	camera->functions->about = camera_about;
 
 	/* Now, tell the filesystem where to get lists, files and info */
 	gp_filesystem_set_funcs (camera->fs, &fsfuncs, camera);
@@ -694,7 +682,7 @@ camera_init (Camera *camera, GPContext *context)
 	gp_port_set_settings(camera->port, settings );
 
 	/* Camera should return either 0x00 or 0x08, depending on
-	 * wether the PRINT button is depressed. Either way, it
+	 * whether the PRINT button is depressed. Either way, it
 	 * should NOT stay 'X'
 	 */
 
