@@ -32,19 +32,7 @@
 
 #include <gphoto2/gphoto2.h>
 
-#ifdef ENABLE_NLS
-#  include <libintl.h>
-#  undef _
-#  define _(String) dgettext (PACKAGE, String)
-#  ifdef gettext_noop
-#    define N_(String) gettext_noop (String)
-#  else
-#    define N_(String) (String)
-#  endif
-#else
-#  define _(String) (String)
-#  define N_(String) (String)
-#endif
+#include "libgphoto2/i18n.h"
 
 #include "digigr8.h"
 
@@ -217,8 +205,8 @@ get_file_func(CameraFilesystem *fs, const char *folder, const char *filename,
 
 	if (GP_FILE_TYPE_EXIF ==type) return GP_ERROR_FILE_EXISTS;
 
-	if (GP_FILE_TYPE_RAW!=type && GP_FILE_TYPE_NORMAL
-				    != type && GP_FILE_TYPE_PREVIEW != type) {
+	if (GP_FILE_TYPE_RAW != type
+		&& GP_FILE_TYPE_NORMAL != type && GP_FILE_TYPE_PREVIEW != type) {
 		return GP_ERROR_NOT_SUPPORTED;
 	}
 
@@ -357,8 +345,7 @@ camera_capture_preview(Camera *camera, CameraFile *file, GPContext *context)
 	gp_port_read(camera->port, (char *)get_size, 0x50);
 	GP_DEBUG("get_size[0x40] = 0x%x\n", get_size[0x40]);
 	lighting = get_size[0x48];
-        b = get_size[0x40] | get_size[0x41] << 8 | get_size[0x42] << 16
-						| get_size[0x43]<<24;
+	b = get_size[0x40] | get_size[0x41] << 8 | get_size[0x42] << 16 | get_size[0x43]<<24;
 	GP_DEBUG("b = 0x%x\n", b);
 	raw_data = malloc(b);
 
@@ -393,7 +380,7 @@ camera_capture_preview(Camera *camera, CameraFile *file, GPContext *context)
 	GP_DEBUG ("size = %i\n", size);
 	gp_ahd_decode (frame_data, w , h , ptr, BAYER_TILE_BGGR);
 	free(frame_data);
-        if (lighting < 0x40) {
+	if (lighting < 0x40) {
 		GP_DEBUG(
 		"Low light condition. Default gamma. No white balance.\n");
 		gp_gamma_fill_table (gtable, .65);
@@ -441,7 +428,7 @@ camera_init(Camera *camera, GPContext *context)
 
 	/* Now, set up all the function pointers */
 	camera->functions->summary	= camera_summary;
-        camera->functions->manual	= camera_manual;
+	camera->functions->manual	= camera_manual;
 	camera->functions->about	= camera_about;
 	camera->functions->capture_preview
 					= camera_capture_preview;
