@@ -38,24 +38,7 @@
 #include "gsmart300.h"
 #include "gsmart300-jpeg-header.h"
 
-#ifdef ENABLE_NLS
-#  include <libintl.h>
-#  undef _
-#  define _(String) dgettext (PACKAGE, String)
-#  ifdef gettext_noop
-#    define N_(String) gettext_noop (String)
-#  else
-#    define N_(String) (String)
-#  endif
-#else
-#  define textdomain(String) (String)
-#  define gettext(String) (String)
-#  define dgettext(Domain,Message) (Message)
-#  define dcgettext(Domain,Message,Type) (Message)
-#  define bindtextdomain(Domain,Directory) (Domain)
-#  define _(String) (String)
-#  define N_(String) (String)
-#endif
+#include "libgphoto2/i18n.h"
 
 #ifdef FUZZING_BUILD_MODE_UNSAFE_FOR_PRODUCTION
 #define sleep(x)
@@ -130,7 +113,7 @@ gsmart300_request_file (CameraPrivateLibrary * lib, CameraFile *file,
 	uint8_t qIndex, value;
 	uint8_t *mybuf;
 	int i, ret;
-	/* NOTE : these varialbes are slightly renamed */
+	/* NOTE : these variables are slightly renamed */
 	int flash_size, data_size, file_size;
 
 	CHECK (gsmart300_get_file_info (lib, number, &g_file));
@@ -161,8 +144,7 @@ gsmart300_request_file (CameraPrivateLibrary * lib, CameraFile *file,
 	if (!mybuf)
 		return GP_ERROR_NO_MEMORY;
 
-	ret = gsmart300_download_data (lib, __GS300_PIC, g_file->index,
-				        flash_size, mybuf);
+	ret = gsmart300_download_data (lib, __GS300_PIC, g_file->index, flash_size, mybuf);
 	if (ret < GP_OK) {
 		free (mybuf);
 		return ret;
@@ -258,8 +240,7 @@ gsmart300_get_image_thumbnail (CameraPrivateLibrary * lib, CameraFile *file,
 	mybuf = malloc (size);
 	if (!mybuf)
 		return (GP_ERROR_NO_MEMORY);
-	ret = gsmart300_download_data (lib, __GS300_THUMB, g_file->index,
-				        size, mybuf);
+	ret = gsmart300_download_data (lib, __GS300_THUMB, g_file->index, size, mybuf);
 	if (ret < GP_OK) {
 		free (mybuf);
 		return ret;
@@ -379,7 +360,6 @@ gsmart300_get_FATs (CameraPrivateLibrary * lib)
 	int index = 0;
 	unsigned int file_index = 0;
 	uint8_t *p = NULL;
-	char buf[14];
 
 	CHECK (gsmart300_get_file_count(lib));
 
@@ -394,20 +374,17 @@ gsmart300_get_FATs (CameraPrivateLibrary * lib)
 	p = lib->fats;
 
 	while (index < lib->num_files) {
-		CHECK (gsmart300_download_data (lib, __GS300_FAT, index,
-					        FLASH_PAGE_SIZE_300, p));
+		CHECK (gsmart300_download_data (lib, __GS300_FAT, index, FLASH_PAGE_SIZE_300, p));
 		if (p[0] == 0xFF)
 			break;
 		type = p[0];
 		if (type == 0x00) {
-			snprintf (buf, 13, "Image%03d.jpg", index + 1);
-			lib->files[file_index].mime_type =
-				GSMART_FILE_TYPE_IMAGE;
+			lib->files[file_index].mime_type = GSMART_FILE_TYPE_IMAGE;
 			lib->files[file_index].index = index;
 			lib->files[file_index].fat = p;
 			lib->files[file_index].width = (p[8] & 0xFF) * 16;
 			lib->files[file_index].height = (p[9] & 0xFF) * 16;
-			lib->files[file_index].name = strdup (buf);
+			lib->files[file_index].name = aprintf ("Image%03d.jpg", index + 1);
 			file_index++;
 		}
 
