@@ -35,19 +35,7 @@
 
 #include <gphoto2/gphoto2.h>
 
-#ifdef ENABLE_NLS
-#  include <libintl.h>
-#  undef _
-#  define _(String) dgettext (PACKAGE, String)
-#  ifdef gettext_noop
-#    define N_(String) gettext_noop (String)
-#  else
-#    define N_(String) (String)
-#  endif
-#else
-#  define _(String) (String)
-#  define N_(String) (String)
-#endif
+#include "libgphoto2/i18n.h"
 
 #include "gsmart300.h"
 
@@ -130,14 +118,10 @@ static int
 camera_exit (Camera *camera, GPContext *context)
 {
 	if (camera->pl) {
-		if (camera->pl->fats) {
-			free (camera->pl->fats);
-			camera->pl->fats = NULL;
-		}
-		if (camera->pl->files) {
-			free (camera->pl->files);
-			camera->pl->files = NULL;
-		}
+		free (camera->pl->fats);
+		camera->pl->fats = NULL;
+		free (camera->pl->files);
+		camera->pl->files = NULL;
 
 		free (camera->pl);
 		camera->pl = NULL;
@@ -264,15 +248,14 @@ get_file_func (CameraFilesystem *fs, const char *folder,
 	Camera *camera = user_data;
 	int number, filetype;
 
-	CHECK (number = gp_filesystem_number (camera->fs, folder, filename,
-				              context));
+	CHECK (number = gp_filesystem_number (camera->fs, folder, filename, context));
 	switch (type) {
 		case GP_FILE_TYPE_NORMAL:
 			CHECK (gsmart300_request_file (camera->pl, file, number));
 			break;
 		case GP_FILE_TYPE_PREVIEW:
 			CHECK (gsmart300_request_thumbnail
-			       (camera->pl, file, number, &filetype));
+				(camera->pl, file, number, &filetype));
 			if (filetype == GSMART_FILE_TYPE_IMAGE) {
 				CHECK (gp_file_set_mime_type (file, GP_MIME_BMP));
 			}
@@ -293,8 +276,7 @@ get_info_func (CameraFilesystem *fs, const char *folder,
 	struct GsmartFile *file;
 
 	/* Get the file number from the CameraFileSystem */
-	CHECK (n = gp_filesystem_number (camera->fs, folder, filename,
-				         context));
+	CHECK (n = gp_filesystem_number (camera->fs, folder, filename, context));
 
 	CHECK (gsmart300_get_file_info (camera->pl, n, &file));
 
@@ -325,17 +307,16 @@ delete_file_func (CameraFilesystem *fs, const char *folder,
 	int n, c;
 
 	/* Get the file number from the CameraFileSystem */
-	CHECK (n = gp_filesystem_number (camera->fs, folder, filename,
-				         context));
+	CHECK (n = gp_filesystem_number (camera->fs, folder, filename, context));
 	CHECK (c = gp_filesystem_count (camera->fs, folder, context));
 	if (n + 1 != c) {
 		const char *name;
 
 		gp_filesystem_name (fs, "/", c - 1, &name, context);
 		gp_context_error (context,
-											_("Your camera only supports deleting "
-												"the last file on the camera. In this "
-												"case, this is file '%s'."), name);
+			_("Your camera only supports deleting "
+				"the last file on the camera. In this "
+				"case, this is file '%s'."), name);
 		return (GP_ERROR);
 	}
 	CHECK (gsmart300_delete_file (camera->pl, n));
