@@ -1,7 +1,7 @@
 /****************************************************************/
 /* library.h  - Gphoto2 library for the KBGear JamCam v2 and v3 */
 /*                                                              */
-/* Copyright  2001 Chris Pinkham                             */
+/* Copyright 2001 Chris Pinkham                                 */
 /*                                                              */
 /* Author: Chris Pinkham <cpinkham@infi.net>                    */
 /*                                                              */
@@ -19,12 +19,12 @@
 /*                                                              */
 /* You should have received a copy of the GNU Library General   */
 /* Public License along with this library; if not, write to the */
-/* Free Software Foundation, Inc., 59 Temple Place - Suite 330, */
-/* Boston, MA 02111-1307, USA.                                  */
+/* Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,*/
+/* Boston, MA  02110-1301  USA					*/
 /****************************************************************/
 
-#ifndef __LIBRARY_H__
-#define __LIBRARY_H__
+#ifndef CAMLIBS_JAMCAM_LIBRARY_H
+#define CAMLIBS_JAMCAM_LIBRARY_H
 
 #define	RETRIES			10
 
@@ -34,16 +34,16 @@
 #define CHECK(result) {int __res; __res = result; if (__res < 0) return (__res);}
 
 struct jamcam_file {
-	int position;
-	int width;
-	int height;
-	int data_incr;
+	unsigned int position;
+	unsigned int width;
+	unsigned int height;
+	unsigned int data_incr;
 };
 
 int jamcam_enq(Camera *camera);
 int jamcam_file_count(Camera *camera);
 struct jamcam_file *jamcam_file_info(Camera *camera, int number);
-int jamcam_request_image(Camera *camera, CameraFile *file, char *buf, int *len, int number, GPContext *context );
-int jamcam_request_thumbnail(Camera *camera, CameraFile *file, char *buf, int *len, int number, GPContext *context );
+int jamcam_request_image(Camera *camera, CameraFile *file, char *buf, unsigned int *len, int number, GPContext *context );
+int jamcam_request_thumbnail(Camera *camera, CameraFile *file, char *buf, unsigned int *len, int number, GPContext *context );
 
-#endif /* __LIBRARY_H__ */
+#endif /* !defined(CAMLIBS_JAMCAM_LIBRARY_H) */
