@@ -28,20 +28,7 @@
 #include "jl2005bcd_decompress.h"
 #include <gphoto2/gphoto2.h>
 
-
-#ifdef ENABLE_NLS
-#  include <libintl.h>
-#  undef _
-#  define _(String) dgettext (PACKAGE, String)
-#  ifdef gettext_noop
-#    define N_(String) gettext_noop (String)
-#  else
-#    define N_(String) (String)
-#  endif
-#else
-#  define _(String) (String)
-#  define N_(String) (String)
-#endif
+#include "libgphoto2/i18n.h"
 
 #include "jl2005c.h"
 #include <gphoto2/gphoto2-port.h>
@@ -453,7 +440,7 @@ camera_init (Camera *camera, GPContext *context)
 	int ret = 0;
 
 	/* First, set up all the function pointers */
-        camera->functions->manual	= camera_manual;
+	camera->functions->manual	= camera_manual;
 	camera->functions->summary	= camera_summary;
 	camera->functions->about	= camera_about;
 	camera->functions->exit		= camera_exit;
