@@ -1,21 +1,21 @@
 /* konica.c
  *
- * Copyright  2001 Lutz Mller
+ * Copyright 2001 Lutz Mueller
  *
  * This library is free software; you can redistribute it and/or
  * modify it under the terms of the GNU Lesser General Public
  * License as published by the Free Software Foundation; either
  * version 2 of the License, or (at your option) any later version.
  *
- * This library is distributed in the hope that it will be useful, 
- * but WITHOUT ANY WARRANTY; without even the implied warranty of 
+ * This library is distributed in the hope that it will be useful,
+ * but WITHOUT ANY WARRANTY; without even the implied warranty of
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
- * Lesser General Public License for more details. 
+ * Lesser General Public License for more details.
  *
  * You should have received a copy of the GNU Lesser General Public
  * License along with this library; if not, write to the
- * Free Software Foundation, Inc., 59 Temple Place - Suite 330,
- * Boston, MA 02111-1307, USA.
+ * Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
+ * Boston, MA  02110-1301  USA
  */
 
 #include "config.h"
@@ -28,26 +28,10 @@
 #include <gphoto2/gphoto2.h>
 #include <gphoto2/gphoto2-port-log.h>
 
+#include "libgphoto2/i18n.h"
+
 #include "lowlevel.h"
 
-#ifdef ENABLE_NLS
-#  include <libintl.h>
-#  undef _
-#  define _(String) dgettext (GETTEXT_PACKAGE, String)
-#  ifdef gettext_noop
-#    define N_(String) gettext_noop (String)
-#  else
-#    define N_(String) (String)
-#  endif
-#else
-#  define textdomain(String) (String)
-#  define gettext(String) (String)
-#  define dgettext(Domain,Message) (Message)
-#  define dcgettext(Domain,Message,Type) (Message)
-#  define bindtextdomain(Domain,Directory) (Domain)
-#  define _(String) (String)
-#  define N_(String) (String)
-#endif
 
 #define GP_MODULE "konica"
 #define CHECK_NULL(r)     {if (!(r)) return (GP_ERROR_BAD_PARAMETERS);}
@@ -138,7 +122,7 @@ k_check (GPContext *c, const unsigned char *rb)
 			"error that has not yet been discovered. Please "
 			"report the following to %s "
 			"with additional information how you got this error: "
-			"(0x%x,0x%x). Thank you very much!"), 
+			"(0x%x,0x%x). Thank you very much!"),
 			MAIL_GPHOTO_DEVEL, rb[2], rb[3]);
 		return (GP_ERROR);
         }
@@ -690,16 +674,16 @@ k_get_information (GPPort *p, GPContext *c, KInformation *info)
 	CRF (c, l_send_receive (p, c, sb, 4, &rb, &rbs, 0, NULL, NULL), rb);
 
 	memset (info, 0, sizeof (KInformation));
-	strncpy (info->model,         &rb[ 8],  4);
-	strncpy (info->serial_number, &rb[12], 10);
+	strncpy (info->model,         (char *)&rb[ 8],  4);
+	strncpy (info->serial_number, (char *)&rb[12], 10);
 	info->hardware.major =         rb[22];
 	info->hardware.minor =         rb[23];
 	info->software.major =         rb[24];
 	info->software.minor =         rb[25];
 	info->testing.major  =         rb[26];
 	info->testing.minor  =         rb[27];
-	strncpy (info->name,          &rb[28], 22);
-	strncpy (info->manufacturer,  &rb[50], 30);
+	strncpy (info->name,          (char *)&rb[28], 22);
+	strncpy (info->manufacturer,  (char *)&rb[50], 30);
 
         free (rb);
         return (GP_OK);
@@ -775,7 +759,7 @@ k_get_status (GPPort *p, GPContext *c, KStatus *status)
 	CHECK_NULL (status);
 
         CRF (c, l_send_receive (p, c, sb, 6, &rb, &rbs, 0, NULL, NULL), rb);
-	
+
 	status->self_test_result = (rb[5] << 8) | rb[4];
 	status->power_level      = rb[6];
 	status->power_source     = rb[7];
@@ -1285,7 +1269,7 @@ k_localization_data_put (GPPort *p, GPContext *c,
 				 * packets but make sure we don't loop
 				 * forever.
 				 */
-				if (i > 131072) 
+				if (i > 131072)
 					return (GP_ERROR);
 			}
 		}
