@@ -115,78 +115,91 @@ camera_abilities (CameraAbilitiesList *list)
 
 	strcpy (a.model, "Pentax:K30");
 	a.usb_vendor		= 0x25fb;
-        a.usb_product           = 0x0132;
-        if (GP_OK != (ret = gp_abilities_list_append (list, a)))
-                return ret;
+	a.usb_product           = 0x0132;
+	if (GP_OK != (ret = gp_abilities_list_append (list, a)))
+		return ret;
 
-        strcpy (a.model, "Pentax:K5II");
+	strcpy (a.model, "Pentax:K5II");
 	a.usb_vendor		= 0x25fb;
-        a.usb_product           = 0x0148;
-        if (GP_OK != (ret = gp_abilities_list_append (list, a)))
-                return ret;
+	a.usb_product           = 0x0148;
+	if (GP_OK != (ret = gp_abilities_list_append (list, a)))
+		return ret;
 
 	/* TommyLimKW @ Twitter */
-        strcpy (a.model, "Pentax:K5IIs");
+	strcpy (a.model, "Pentax:K5IIs");
 	a.usb_vendor		= 0x25fb;
-        a.usb_product           = 0x014a;
-        if (GP_OK != (ret = gp_abilities_list_append (list, a)))
-                return ret;
+	a.usb_product           = 0x014a;
+	if (GP_OK != (ret = gp_abilities_list_append (list, a)))
+		return ret;
 
-        strcpy (a.model, "Pentax:K3");
+	strcpy (a.model, "Pentax:K3");
 	a.usb_vendor		= 0x25fb;
-        a.usb_product           = 0x0164;
-        if (GP_OK != (ret = gp_abilities_list_append (list, a)))
-                return ret;
+	a.usb_product           = 0x0164;
+	if (GP_OK != (ret = gp_abilities_list_append (list, a)))
+		return ret;
 
-        strcpy (a.model, "Pentax:K1");
+	strcpy (a.model, "Pentax:K1");
 	a.usb_vendor		= 0x25fb;
-        a.usb_product           = 0x0178;
-        if (GP_OK != (ret = gp_abilities_list_append (list, a)))
-                return ret;
+	a.usb_product           = 0x0178;
+	if (GP_OK != (ret = gp_abilities_list_append (list, a)))
+		return ret;
 
-        strcpy (a.model, "Pentax:K3II");
+	strcpy (a.model, "Pentax:K3II");
 	a.usb_vendor		= 0x25fb;
-        a.usb_product           = 0x017a;
-        if (GP_OK != (ret = gp_abilities_list_append (list, a)))
-                return ret;
+	a.usb_product           = 0x017a;
+	if (GP_OK != (ret = gp_abilities_list_append (list, a)))
+		return ret;
 
 	/* Keld Henningsen <drawsacircle@hotmail.com> */
-        strcpy (a.model, "Pentax:K70");
+	strcpy (a.model, "Pentax:K70");
 	a.usb_vendor		= 0x25fb;
-        a.usb_product           = 0x017c;
-        if (GP_OK != (ret = gp_abilities_list_append (list, a)))
-                return ret;
+	a.usb_product           = 0x017c;
+	if (GP_OK != (ret = gp_abilities_list_append (list, a)))
+		return ret;
 	/* fifu7fi@gmail.com */
-        strcpy (a.model, "Pentax:KP");
+	strcpy (a.model, "Pentax:KP");
 	a.usb_vendor		= 0x25fb;
-        a.usb_product           = 0x017e;
-        if (GP_OK != (ret = gp_abilities_list_append (list, a)))
-                return ret;
-	return GP_OK;
+	a.usb_product           = 0x017e;
+	if (GP_OK != (ret = gp_abilities_list_append (list, a)))
+		return ret;
 
+	/* https://github.com/asalamon74/pktriggercord/issues/21 */
+	strcpy (a.model, "Pentax:K1II");
+	a.usb_vendor		= 0x25fb;
+	a.usb_product           = 0x0183;
+	if (GP_OK != (ret = gp_abilities_list_append (list, a)))
+		return ret;
+
+	strcpy (a.model, "Pentax:K3III");
+	a.usb_vendor		= 0x25fb;
+	a.usb_product           = 0x0189;
+	if (GP_OK != (ret = gp_abilities_list_append (list, a)))
+		return ret;
+
+	return GP_OK;
 }
 
 int scsi_write(GPPort *port, uint8_t *cmd, uint32_t cmdLen,
                uint8_t *buf, uint32_t bufLen) {
-        int ret;
-        char sense_buffer[32];
+	int ret;
+	char sense_buffer[32];
 
-        ret = gp_port_send_scsi_cmd (port, 1, (char*)cmd, cmdLen,
-                sense_buffer, sizeof(sense_buffer), (char*)buf, bufLen);
-        if (ret == GP_OK) return PSLR_OK;
-        return PSLR_SCSI_ERROR;
+	ret = gp_port_send_scsi_cmd (port, 1, (char*)cmd, cmdLen,
+		sense_buffer, sizeof(sense_buffer), (char*)buf, bufLen);
+	if (ret == GP_OK) return PSLR_OK;
+	return PSLR_SCSI_ERROR;
 }
 
 int scsi_read(GPPort *port, uint8_t *cmd, uint32_t cmdLen,
               uint8_t *buf, uint32_t bufLen)
 {
-        int ret;
-        char sense_buffer[32];
+	int ret;
+	char sense_buffer[32];
 
-        ret = gp_port_send_scsi_cmd (port, 0, (char*)cmd, cmdLen,
-                sense_buffer, sizeof(sense_buffer), (char*)buf, bufLen);
-        if (ret == GP_OK) return bufLen;
-        return -PSLR_SCSI_ERROR;
+	ret = gp_port_send_scsi_cmd (port, 0, (char*)cmd, cmdLen,
+		sense_buffer, sizeof(sense_buffer), (char*)buf, bufLen);
+	if (ret == GP_OK) return bufLen;
+	return -PSLR_SCSI_ERROR;
 }
 
 void close_drive(GPPort **port) {
@@ -204,7 +217,7 @@ camera_summary (Camera *camera, CameraText *summary, GPContext *context)
 
 	pslr_get_status (&camera->pl->pslr, &status);
 
-	statusinfo = collect_status_info( &camera->pl->pslr, status );
+	statusinfo = pslr_get_status_info( &camera->pl->pslr, status );
 
 	sprintf (summary->text, _(
 		"Pentax K DSLR capture driver.\n"
@@ -315,7 +328,7 @@ camera_capture (Camera *camera, CameraCaptureType type, CameraFilePath *path,
 	const char		*mimes[2];
 	int			buftypes[2], jpegres[2], nrofdownloads = 1;
 	char			*fns[2], *lastfn = NULL;
-        struct timeval  	event_start;
+	struct timeval  	event_start;
 
 	gp_log (GP_LOG_DEBUG, "pentax", "camera_capture");
 
@@ -458,7 +471,7 @@ static int
 camera_wait_for_event (Camera *camera, int timeout,
                        CameraEventType *eventtype, void **eventdata,
                        GPContext *context) {
-        struct timeval  event_start;
+	struct timeval  event_start;
 	CameraFilePath	*path;
 	pslr_handle_t	p = &camera->pl->pslr;
 	int		ret, length;
@@ -618,7 +631,7 @@ camera_get_config (Camera *camera, CameraWidget **window, GPContext *context)
 
 	pslr_get_status (&camera->pl->pslr, &status);
 
-	model = pslr_camera_name (&camera->pl->pslr);
+	model = pslr_get_camera_name (&camera->pl->pslr);
 
 	available_resolutions = pslr_get_model_jpeg_resolutions (&camera->pl->pslr);
 
@@ -775,15 +788,15 @@ camera_get_config (Camera *camera, CameraWidget **window, GPContext *context)
 	gp_widget_add_choice (t, _("B"));
 	gp_widget_add_choice (t, _("X"));
 	switch (status.exposure_mode) {
-	case PSLR_GUI_EXPOSURE_MODE_GREEN:	gp_widget_set_value (t, _("GREEN"));break;
-	case PSLR_GUI_EXPOSURE_MODE_M:		gp_widget_set_value (t, _("M"));break;
-	case PSLR_GUI_EXPOSURE_MODE_P:		gp_widget_set_value (t, _("P"));break;
-	case PSLR_GUI_EXPOSURE_MODE_AV:		gp_widget_set_value (t, _("AV"));break;
-	case PSLR_GUI_EXPOSURE_MODE_TV:		gp_widget_set_value (t, _("TV"));break;
-	case PSLR_GUI_EXPOSURE_MODE_SV:		gp_widget_set_value (t, _("SV"));break;
-	case PSLR_GUI_EXPOSURE_MODE_TAV:	gp_widget_set_value (t, _("TAV"));break;
-	case PSLR_GUI_EXPOSURE_MODE_X:		gp_widget_set_value (t, _("X"));break;
-	case PSLR_GUI_EXPOSURE_MODE_B:		gp_widget_set_value (t, _("B"));break;
+	case PSLR_EXPOSURE_MODE_GREEN:	gp_widget_set_value (t, _("GREEN"));break;
+	case PSLR_EXPOSURE_MODE_M:		gp_widget_set_value (t, _("M"));break;
+	case PSLR_EXPOSURE_MODE_P:		gp_widget_set_value (t, _("P"));break;
+	case PSLR_EXPOSURE_MODE_AV:		gp_widget_set_value (t, _("AV"));break;
+	case PSLR_EXPOSURE_MODE_TV:		gp_widget_set_value (t, _("TV"));break;
+	case PSLR_EXPOSURE_MODE_SV:		gp_widget_set_value (t, _("SV"));break;
+	case PSLR_EXPOSURE_MODE_TAV:	gp_widget_set_value (t, _("TAV"));break;
+	case PSLR_EXPOSURE_MODE_X:		gp_widget_set_value (t, _("X"));break;
+	case PSLR_EXPOSURE_MODE_B:		gp_widget_set_value (t, _("B"));break;
 	default:
 		sprintf(buf, _("Unknown mode %d"), status.exposure_mode);
 		gp_widget_set_value (t, buf);
@@ -816,12 +829,12 @@ camera_set_config (Camera *camera, CameraWidget *window, GPContext *context)
 		int i, resolution = -1;
 		int *valid_resolutions;
 
-	        gp_widget_set_changed (w, 0);
+		gp_widget_set_changed (w, 0);
 		valid_resolutions = pslr_get_model_jpeg_resolutions (&camera->pl->pslr);
 
 		gp_widget_get_value (w, &sval);
 		for (i = 0; i < MAX_RESOLUTION_SIZE; i++)
-	        {
+		{
 			int foo;
 
 			sscanf(sval, "%d", &foo);
@@ -839,22 +852,22 @@ camera_set_config (Camera *camera, CameraWidget *window, GPContext *context)
 
 	ret = gp_widget_get_child_by_label (window, _("Shooting Mode"), &w);
 	if ((ret == GP_OK) && gp_widget_changed (w)) {
-		pslr_gui_exposure_mode_t exposuremode;
+		pslr_exposure_mode_t exposuremode;
 
-	        gp_widget_set_changed (w, 0);
+		gp_widget_set_changed (w, 0);
 		gp_widget_get_value (w, &sval);
 
-		exposuremode = PSLR_GUI_EXPOSURE_MODE_MAX;
-		if (!strcmp(sval,_("GREEN")))	exposuremode = PSLR_GUI_EXPOSURE_MODE_GREEN;
-		if (!strcmp(sval,_("M")))	exposuremode = PSLR_GUI_EXPOSURE_MODE_M;
-		if (!strcmp(sval,_("B")))	exposuremode = PSLR_GUI_EXPOSURE_MODE_B;
-		if (!strcmp(sval,_("P")))	exposuremode = PSLR_GUI_EXPOSURE_MODE_P;
-		if (!strcmp(sval,_("SV")))	exposuremode = PSLR_GUI_EXPOSURE_MODE_SV;
-		if (!strcmp(sval,_("TV")))	exposuremode = PSLR_GUI_EXPOSURE_MODE_TV;
-		if (!strcmp(sval,_("AV")))	exposuremode = PSLR_GUI_EXPOSURE_MODE_AV;
-		if (!strcmp(sval,_("TAV")))	exposuremode = PSLR_GUI_EXPOSURE_MODE_TAV;
-		if (!strcmp(sval,_("X")))	exposuremode = PSLR_GUI_EXPOSURE_MODE_TAV;
-		if (exposuremode != PSLR_GUI_EXPOSURE_MODE_MAX) {
+		exposuremode = PSLR_EXPOSURE_MODE_MAX;
+		if (!strcmp(sval,_("GREEN")))	exposuremode = PSLR_EXPOSURE_MODE_GREEN;
+		if (!strcmp(sval,_("M")))	exposuremode = PSLR_EXPOSURE_MODE_M;
+		if (!strcmp(sval,_("B")))	exposuremode = PSLR_EXPOSURE_MODE_B;
+		if (!strcmp(sval,_("P")))	exposuremode = PSLR_EXPOSURE_MODE_P;
+		if (!strcmp(sval,_("SV")))	exposuremode = PSLR_EXPOSURE_MODE_SV;
+		if (!strcmp(sval,_("TV")))	exposuremode = PSLR_EXPOSURE_MODE_TV;
+		if (!strcmp(sval,_("AV")))	exposuremode = PSLR_EXPOSURE_MODE_AV;
+		if (!strcmp(sval,_("TAV")))	exposuremode = PSLR_EXPOSURE_MODE_TAV;
+		if (!strcmp(sval,_("X")))	exposuremode = PSLR_EXPOSURE_MODE_TAV;
+		if (exposuremode != PSLR_EXPOSURE_MODE_MAX) {
 			pslr_set_exposure_mode(&camera->pl->pslr, exposuremode);
 			pslr_get_status(&camera->pl->pslr, &status);
 		} else {
@@ -866,7 +879,7 @@ camera_set_config (Camera *camera, CameraWidget *window, GPContext *context)
 	if ((ret == GP_OK) && gp_widget_changed (w)) {
 		int iso;
 
-	        gp_widget_set_changed (w, 0);
+		gp_widget_set_changed (w, 0);
 		gp_widget_get_value (w, &sval);
 		if (sscanf(sval, "%d", &iso)) {
 			/* pslr_set_iso(&camera->pl->pslr, iso); */
@@ -886,7 +899,7 @@ camera_set_config (Camera *camera, CameraWidget *window, GPContext *context)
 		rational.denom = 10;
 		rational.nom = (int)(10 * fval);
 
-		pslr_set_ec (&camera->pl->pslr, rational);
+		pslr_set_expose_compensation (&camera->pl->pslr, rational);
 
 	}
 
@@ -897,7 +910,7 @@ camera_set_config (Camera *camera, CameraWidget *window, GPContext *context)
 		/* FIXME: decoding is strange. the UI shows number of stars
 		 * on k20d: 4 stars = 3, 3 stars = 0, 2 stars = 1, 1 star = 2
 		 */
-	        gp_widget_set_changed (w, 0);
+		gp_widget_set_changed (w, 0);
 		gp_widget_get_value (w, &sval);
 		if (sscanf(sval, "%d", &qual)) {
 			pslr_set_jpeg_stars (&camera->pl->pslr, qual);
@@ -910,7 +923,7 @@ camera_set_config (Camera *camera, CameraWidget *window, GPContext *context)
 	if ((ret == GP_OK) && gp_widget_changed (w)) {
 		pslr_rational_t speed;
 
-	        gp_widget_set_changed (w, 0);
+		gp_widget_set_changed (w, 0);
 		gp_widget_get_value (w, &sval);
 		if (sscanf(sval, "%d/%d", &speed.nom, &speed.denom)) {
 			pslr_set_shutter(&camera->pl->pslr, speed);
@@ -933,7 +946,7 @@ camera_set_config (Camera *camera, CameraWidget *window, GPContext *context)
 		pslr_rational_t aperture;
 		int apt1,apt2;
 
-	        gp_widget_set_changed (w, 0);
+		gp_widget_set_changed (w, 0);
 		gp_widget_get_value (w, &sval);
 		if (sscanf(sval, "%d.%d", &apt1, &apt2)) {
 			if (apt1<11) {
@@ -965,12 +978,12 @@ camera_set_config (Camera *camera, CameraWidget *window, GPContext *context)
 	if ((ret == GP_OK) && gp_widget_changed (w)) {
 		int bulb;
 
-		if (status.exposure_mode != PSLR_GUI_EXPOSURE_MODE_B) {
+		if (status.exposure_mode != PSLR_EXPOSURE_MODE_B) {
 			gp_context_error (context, _("You need to switch the shooting mode or the camera to 'B' for bulb exposure."));
 			return GP_ERROR;
 		}
 
-	        gp_widget_set_changed (w, 0);
+		gp_widget_set_changed (w, 0);
 		gp_widget_get_value (w, &bulb);
 		pslr_bulb (&camera->pl->pslr, bulb);
 
@@ -1008,7 +1021,7 @@ camera_init (Camera *camera, GPContext *context)
 {
 	CameraPrivateLibrary	*cpl;
 
-	cpl = calloc (sizeof (CameraPrivateLibrary), 1);
+	cpl = calloc (1, sizeof (CameraPrivateLibrary));
 	/* pslr = pslr_init (model, device); ... but it basically just opens the fd */
 	cpl->pslr.fd = camera->port;
 
