@@ -153,7 +153,7 @@ struct _PDCPicInfo {
 static const char *quality[] = {N_("normal"), N_("fine"), N_("superfine"),
 				NULL};
 static const char *flash[]   = {N_("auto"), N_("on"), N_("off"), NULL};
-static const char *bool[]    = {N_("off"), N_("on"), NULL};
+static const char *onoff[]    = {N_("off"), N_("on"), NULL};
 static const char *mode[]    = {N_("play"), N_("record"), N_("menu"), NULL};
 static const char *power[]   = {N_("battery"), N_("a/c adaptor"), NULL};
 /* no real need to translate those ... */
@@ -509,7 +509,7 @@ pdc700_info (Camera *camera, PDCInfo *info, GPContext *context)
 	 * 01 20 .. 02
 	 */
 
- 	info->memory = buf[2];
+	info->memory = buf[2];
 
 	/* Power source state (make sure it's valid) */
 	info->ac_power = buf[4];
@@ -518,7 +518,7 @@ pdc700_info (Camera *camera, PDCInfo *info, GPContext *context)
 		info->ac_power = PDC_BOOL_OFF;
 	}
 
- 	info->auto_poweroff = buf[5];
+	info->auto_poweroff = buf[5];
 
 	/* Mode (make sure we know it) */
 	info->mode = buf[6];
@@ -636,16 +636,16 @@ pdc700_set_date (Camera *camera, time_t time, GPContext *context)
 static int
 pdc700_capture (Camera *camera, GPContext *context)
 {
-        unsigned char cmd[5], buf[1024];
-        unsigned int buf_len = 0;
+	unsigned char cmd[5], buf[1024];
+	unsigned int buf_len = 0;
 	int r = 0;
 	int try;
 	PDCInfo info;
 
-        cmd[3] = PDC700_CAPTURE;
+	cmd[3] = PDC700_CAPTURE;
 	cmd[4] = 0;
 
-        CR (pdc700_transmit (camera, cmd, 5, buf, &buf_len, context));
+	CR (pdc700_transmit (camera, cmd, 5, buf, &buf_len, context));
 
 	/*
 	 * This is rather hackish.  The camera needs a little time to recover
@@ -654,10 +654,10 @@ pdc700_capture (Camera *camera, GPContext *context)
 	 * I'm leaving this ugly-but-works junk here for now.
 	 */
 	for (try = 0; try < 10; try++)
-	  if ((r = pdc700_info(camera, &info, context)) == GP_OK)
-	    break;
+		if ((r = pdc700_info(camera, &info, context)) == GP_OK)
+			break;
 
-        return r;
+	return r;
 };
 
 static int
@@ -746,7 +746,7 @@ camera_abilities (CameraAbilitiesList *list)
 		a.speed[3] = 57600;
 		a.speed[4] = 115200;
 		a.operations        = GP_OPERATION_CAPTURE_IMAGE |
-                                      GP_OPERATION_CONFIG;
+		                      GP_OPERATION_CONFIG;
 		a.file_operations   = GP_FILE_OPERATION_DELETE |
 		                      GP_FILE_OPERATION_PREVIEW;
 		a.folder_operations = GP_FOLDER_OPERATION_DELETE_ALL;
@@ -972,9 +972,9 @@ camera_get_config (Camera *camera, CameraWidget **window, GPContext *context)
 	gp_widget_new (GP_WIDGET_SECTION, _("Camera"), &section);
 	gp_widget_append (*window, section);
 
-	add_radio (section, LCD_STATE,     bool,    info.lcd);
-	add_radio (section, SELF_TIMER,    bool,    info.timer);
-	add_radio (section, SHOW_CAPTIONS, bool,    info.caption);
+	add_radio (section, LCD_STATE,     onoff,    info.lcd);
+	add_radio (section, SELF_TIMER,    onoff,    info.timer);
+	add_radio (section, SHOW_CAPTIONS, onoff,    info.caption);
 
 	/* Auto poweroff */
 	gp_widget_new (GP_WIDGET_RANGE, AUTO_POWEROFF, &child);
@@ -1015,7 +1015,7 @@ static int
 which_radio_button (CameraWidget *window, const char *label,
 		    const char * const *opt)
 {
-  	CameraWidget *child;
+	CameraWidget *child;
 	int i;
 	const char *value;
 
@@ -1038,7 +1038,7 @@ which_radio_button (CameraWidget *window, const char *label,
 static int
 camera_set_config (Camera *camera, CameraWidget *window, GPContext *context)
 {
-  	CameraWidget *child;
+	CameraWidget *child;
 	int i = 0, r;
 	float range;
 
@@ -1054,15 +1054,15 @@ camera_set_config (Camera *camera, CameraWidget *window, GPContext *context)
 		CR (pdc700_config (camera, PDC_CONF_FLASH,
 				   (unsigned char) i, context));
 
-	if ((i = which_radio_button (window, LCD_STATE, bool)) >= 0)
+	if ((i = which_radio_button (window, LCD_STATE, onoff)) >= 0)
 		CR (pdc700_config (camera, PDC_CONF_LCD,
 				   (unsigned char) i, context));
 
-	if ((i = which_radio_button (window, SELF_TIMER, bool)) >= 0)
+	if ((i = which_radio_button (window, SELF_TIMER, onoff)) >= 0)
 		CR (pdc700_config (camera, PDC_CONF_TIMER,
 				   (unsigned char) i, context));
 
-	if ((i = which_radio_button (window, SHOW_CAPTIONS, bool)) >= 0)
+	if ((i = which_radio_button (window, SHOW_CAPTIONS, onoff)) >= 0)
 		CR (pdc700_config (camera, PDC_CONF_CAPTION,
 				   (unsigned char) i, context));
 
@@ -1083,7 +1083,7 @@ camera_set_config (Camera *camera, CameraWidget *window, GPContext *context)
 		if (i != -1)
 		  pdc700_set_date(camera, (time_t) i, context);
 		else
-		  GP_DEBUG ("date widget returned -1, not setting datee/time");
+		  GP_DEBUG ("date widget returned -1, not setting date/time");
 		/* GP_DEBUG ("Implement setting of date & time!"); */
 	}
 
@@ -1123,9 +1123,9 @@ camera_summary (Camera *camera, CameraText *about, GPContext *context)
 		_(mode[info.mode]),
 		_(quality[info.quality]),
 		_(flash[info.flash]),
-		_(bool[info.caption]),
-		_(bool[info.timer]),
-		_(bool[info.lcd]),
+		_(onoff[info.caption]),
+		_(onoff[info.timer]),
+		_(onoff[info.lcd]),
 		info.auto_poweroff,
 		_(power[info.ac_power]));
 
@@ -1182,10 +1182,10 @@ camera_init (Camera *camera, GPContext *context)
 	GPPortSettings settings;
 	int speeds[] = {115200, 9600, 57600, 19200, 38400};
 
-        /* First, set up all the function pointers */
+	/* First, set up all the function pointers */
 	camera->functions->capture = camera_capture;
 	camera->functions->summary = camera_summary;
-        camera->functions->about   = camera_about;
+	camera->functions->about   = camera_about;
 	camera->functions->get_config = camera_get_config;
 	camera->functions->set_config = camera_set_config;
 
