@@ -3,7 +3,7 @@
  * Special device flags to deal with bugs in specific devices.
  *
  * Copyright (C) 2005-2007 Richard A. Low <richard@wentnet.com>
- * Copyright (C) 2005-2011 Linus Walleij <triad@df.lth.se>
+ * Copyright (C) 2005-2012 Linus Walleij <triad@df.lth.se>
  * Copyright (C) 2006-2007 Marcus Meissner
  * Copyright (C) 2007 Ted Bullock
  *
@@ -19,8 +19,8 @@
  *
  * You should have received a copy of the GNU Lesser General Public
  * License along with this library; if not, write to the
- * Free Software Foundation, Inc., 59 Temple Place - Suite 330,
- * Boston, MA 02111-1307, USA.
+ * Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
+ * Boston, MA  02110-1301  USA
  *
  * This file is supposed to be included by both libmtp and libgphoto2.
  */
@@ -80,11 +80,11 @@
  * (64 bytes).
  *
  * This behaviour is most probably a workaround due to the fact
- * that the hardware USB slave controller in the device cannot
- * handle zero writes at all, and the usage of the USB 1.1
- * endpoint size is due to the fact that the device will "gear
- * down" on a USB 1.1 hub, and since 64 bytes is a multiple of
- * 512 bytes, it will work with USB 1.1 and USB 2.0 alike.
+ * that the USB controller in the device cannot handle zero writes
+ * at all, and the usage of the USB 1.1 endpoint size is due to the
+ * fact that the device will "gear down" on a USB 1.1 hub, and since
+ * 64 bytes is a multiple of 512 bytes, it will work with USB 1.1 and
+ * USB 2.0 alike.
  */
 #define DEVICE_FLAG_NO_ZERO_READS 0x00000008
 /**
@@ -129,7 +129,8 @@
  * on Windows anyway, probably because the Windows implementation
  * does not check that these bytes are valid. To interoperate
  * with devices like this, we need this flag to emulate the
- * Windows bug.
+ * Windows bug. Broken headers has also been found in the
+ * Aricent MTP stack.
  */
 #define DEVICE_FLAG_IGNORE_HEADER_ERRORS 0x00000080
 /**
@@ -170,7 +171,7 @@
  */
 #define DEVICE_FLAG_ALWAYS_PROBE_DESCRIPTOR 0x00000800
 /**
- * Samsung has implimented its own playlist format as a .spl file
+ * Samsung has implemented its own playlist format as a .spl file
  * stored in the normal file system, rather than a proper mtp
  * playlist. There are multiple versions of the .spl format
  * identified by a line in the file: VERSION X.XX
@@ -178,7 +179,7 @@
  */
 #define DEVICE_FLAG_PLAYLIST_SPL_V1 0x00001000
 /**
- * Samsung has implimented its own playlist format as a .spl file
+ * Samsung has implemented its own playlist format as a .spl file
  * stored in the normal file system, rather than a proper mtp
  * playlist. There are multiple versions of the .spl format
  * identified by a line in the file: VERSION X.XX
@@ -230,6 +231,12 @@
  */
 #define DEVICE_FLAG_NIKON_BROKEN_CAPTURE	0x00100000
 
+/**
+ * To distinguish the V1 series from the DSLRs and handle them
+ * (libgphoto2)
+ */
+#define DEVICE_FLAG_NIKON_1			0x00200000
+
 /**
  * Broken capture support where cameras do not send CaptureComplete events.
  * (libgphoto2)
@@ -240,7 +247,7 @@
  * Direct PTP match required.
  * (libgphoto2)
  */
-#define DEVICE_FLAG_MATCH_PTP_INTERFACE		0x00800000
+#define DEVICE_FLAG_OLYMPUS_XML_WRAPPED		0x00800000
 /**
  * This flag is like DEVICE_FLAG_OGG_IS_UNKNOWN but for FLAC
  * files instead. Using the unknown filetype for FLAC files.
@@ -268,11 +275,10 @@
  */
 #define DEVICE_FLAG_FORCE_RESET_ON_CLOSE	0x10000000
 /**
- * Early Creative Zen (etc) models actually only support
- * command 9805 (Get object property list) and will hang
- * if you try to get individual properties of an object.
+ * On 2016 EOS cameras, do not close the session on exiting,
+ * as the device will only report ptp errors afterwards.
  */
-#define DEVICE_FLAG_BROKEN_GET_OBJECT_PROPVAL	0x20000000
+#define DEVICE_FLAG_DONT_CLOSE_SESSION          0x20000000
 /**
  * It seems that some devices return an bad data when
  * using the GetObjectInfo operation. So in these cases
@@ -284,6 +290,15 @@
  * 32 bit.
  */
 #define DEVICE_FLAG_PROPLIST_OVERRIDES_OI	0x40000000
+/**
+ * The MTP stack of Samsung Galaxy devices has a mysterious bug in
+ * GetPartialObject. When GetPartialObject is invoked to read the last
+ * bytes of a file and the amount of data to read is such that the
+ * last USB packet sent in the reply matches exactly the USB 2.0
+ * packet size, then the Samsung Galaxy device hangs, resulting in a
+ * timeout error.
+ */
+#define DEVICE_FLAG_SAMSUNG_OFFSET_BUG		0x80000000
 
 /**
  * All these bug flags need to be set on SONY NWZ Walkman
@@ -294,7 +309,7 @@
   (DEVICE_FLAG_UNLOAD_DRIVER | \
    DEVICE_FLAG_BROKEN_MTPGETOBJPROPLIST | \
    DEVICE_FLAG_UNIQUE_FILENAMES | \
-   DEVICE_FLAG_FORCE_RESET_ON_CLOSE )
+   DEVICE_FLAG_FORCE_RESET_ON_CLOSE)
 /**
  * All these bug flags need to be set on Android devices,
  * they claim to support MTP operations they actually
@@ -307,4 +322,23 @@
    DEVICE_FLAG_BROKEN_SET_OBJECT_PROPLIST | \
    DEVICE_FLAG_BROKEN_SEND_OBJECT_PROPLIST | \
    DEVICE_FLAG_UNLOAD_DRIVER | \
-   DEVICE_FLAG_LONG_TIMEOUT )
+   DEVICE_FLAG_LONG_TIMEOUT | \
+   DEVICE_FLAG_FORCE_RESET_ON_CLOSE)
+/**
+ * All these bug flags appear on a number of SonyEricsson
+ * devices including Android devices not using the stock
+ * Android 4.0+ (Ice Cream Sandwich) MTP stack. It is highly
+ * supected that these bugs comes from an MTP implementation
+ * from Aricent, so it is called the Aricent bug flags as a
+ * shorthand. Especially the header errors that need to be
+ * ignored is typical for this stack.
+ *
+ * After some guesswork we auto-assign these bug flags to
+ * devices that present the "microsoft.com/WPDNA", and
+ * "sonyericsson.com/SE" but NOT the "android.com"
+ * descriptor.
+ */
+#define DEVICE_FLAGS_ARICENT_BUGS \
+  (DEVICE_FLAG_IGNORE_HEADER_ERRORS | \
+   DEVICE_FLAG_BROKEN_SEND_OBJECT_PROPLIST | \
+   DEVICE_FLAG_BROKEN_MTPGETOBJPROPLIST)
