@@ -36,6 +36,7 @@
 #include <string.h>
 #include <stdio.h>
 #include <time.h>
+#include <unistd.h>
 #include <errno.h>
 #include <sys/types.h>
 #ifdef HAVE_SYS_SELECT_H
@@ -50,42 +51,23 @@
 #else
 # include <sys/socket.h>
 # include <netinet/in.h>
+# include <arpa/inet.h>
+# include <fcntl.h>
 #endif
 
 #include <gphoto2/gphoto2-library.h>
 #include <gphoto2/gphoto2-port-log.h>
 #include <gphoto2/gphoto2-setting.h>
 
+#include "libgphoto2/i18n.h"
+
 #include "ptp.h"
 #include "ptp-private.h"
+#include "ptp-bugs.h"
 
 #define PTPIP_VERSION_MAJOR 0x0001
 #define PTPIP_VERSION_MINOR 0x0000
 
-#ifdef ENABLE_NLS
-#  include <libintl.h>
-#  undef _
-#  define _(String) dgettext (GETTEXT_PACKAGE, String)
-#  ifdef gettext_noop
-#    define N_(String) gettext_noop (String)
-#  else
-#    define N_(String) (String)
-#  endif
-#else
-#  define textdomain(String) (String)
-#  define gettext(String) (String)
-#  define dgettext(Domain,Message) (Message)
-#  define dcgettext(Domain,Message,Type) (Message)
-#  define bindtextdomain(Domain,Directory) (Domain)
-#  define _(String) (String)
-#  define N_(String) (String)
-#endif
-
-#include "ptp.h"
-#include "ptp-bugs.h"
-
-#include "ptp-pack.c"
-
 #define ptpip_len		0
 #define ptpip_type		4
 
@@ -146,11 +128,13 @@ ptp_ptpip_sendreq (PTPParams* params, PTPContainer* req, int dataphase)
 		break;
 	}
 	GP_LOG_DATA ( (char*)request, len, "ptpip/oprequest data:");
-	ret = PTPSOCK_WRITE(params->cmdfd, request, len);
+	ret = ptpip_write_with_timeout(params->cmdfd, request, len, PTPIP_DEFAULT_TIMEOUT_S, PTPIP_DEFAULT_TIMEOUT_MS);
 	free (request);
 	if (ret == PTPSOCK_ERR) {
-		perror ("sendreq/write to cmdfd");
-		return GP_ERROR_IO;
+		ptpip_perror ("sendreq/write to cmdfd");
+		if (ptpip_get_socket_error() == ETIMEDOUT)
+			return PTP_ERROR_TIMEOUT;
+		return PTP_ERROR_IO;
 	}
 	if (ret != len) {
 		GP_LOG_E ("ptp_ptpip_sendreq() len =%d but ret=%d", len, ret);
@@ -166,10 +150,12 @@ ptp_ptpip_generic_read (PTPParams *params, int fd, PTPIPHeader *hdr, unsigned ch
 
 	xhdr = (unsigned char*)hdr; curread = 0; len = sizeof (PTPIPHeader);
 	while (curread < len) {
-		ret = PTPSOCK_READ (fd, xhdr + curread, len - curread);
+		ret = ptpip_read_with_timeout (fd, xhdr + curread, len - curread, PTPIP_DEFAULT_TIMEOUT_S, PTPIP_DEFAULT_TIMEOUT_MS);
 		if (ret == PTPSOCK_ERR) {
-			perror ("read PTPIPHeader");
-			return PTP_RC_GeneralError;
+			ptpip_perror ("read PTPIPHeader");
+			if (ptpip_get_socket_error() == ETIMEDOUT)
+				return PTP_ERROR_TIMEOUT;
+			return PTP_ERROR_IO;
 		}
 		GP_LOG_DATA ((char*)xhdr+curread, ret, "ptpip/generic_read header:");
 		curread += ret;
@@ -190,11 +176,13 @@ ptp_ptpip_generic_read (PTPParams *params, int fd, PTPIPHeader *hdr, unsigned ch
 	}
 	curread = 0;
 	while (curread < len) {
-		ret = PTPSOCK_READ (fd, (*data)+curread, len-curread);
+		ret = ptpip_read_with_timeout (fd, (*data)+curread, len-curread, PTPIP_DEFAULT_TIMEOUT_S, PTPIP_DEFAULT_TIMEOUT_MS);
 		if (ret == PTPSOCK_ERR) {
-			GP_LOG_E ("error %d in reading PTPIP data", errno);
+			GP_LOG_E ("error %d in reading PTPIP data", ptpip_get_socket_error());
 			free (*data);*data = NULL;
-			return PTP_RC_GeneralError;
+			if (ptpip_get_socket_error() == ETIMEDOUT)
+				return PTP_ERROR_TIMEOUT;
+			return PTP_ERROR_IO;
 		} else {
 			GP_LOG_DATA ((char*)((*data)+curread), ret, "ptpip/generic_read data:");
 		}
@@ -258,10 +246,12 @@ ptp_ptpip_senddata (PTPParams* params, PTPContainer* ptp,
 	htod32a(&request[ptpip_startdata_totallen + 8],size);
 	htod32a(&request[ptpip_startdata_unknown  + 8],0);
 	GP_LOG_DATA ((char*)request, sizeof(request), "ptpip/senddata header:");
-	ret = PTPSOCK_WRITE (params->cmdfd, request, sizeof(request));
+	ret = ptpip_write_with_timeout (params->cmdfd, request, sizeof(request), PTPIP_DEFAULT_TIMEOUT_S, PTPIP_DEFAULT_TIMEOUT_MS);
 	if (ret == PTPSOCK_ERR) {
-		perror ("sendreq/write to cmdfd");
-		return GP_ERROR_IO;
+		ptpip_perror ("sendreq/write to cmdfd");
+		if (ptpip_get_socket_error() == ETIMEDOUT)
+			return PTP_ERROR_TIMEOUT;
+		return PTP_ERROR_IO;
 	}
 	if (ret != sizeof(request)) {
 		GP_LOG_E ("ptp_ptpip_senddata() len=%d but ret=%d", (int)sizeof(request), ret);
@@ -284,7 +274,7 @@ ptp_ptpip_senddata (PTPParams* params, PTPContainer* ptp,
 		}
 		ret = handler->getfunc (params, handler->priv, towrite, &xdata[ptpip_data_payload+8], &xtowrite);
 		if (ret == -1) {
-			perror ("getfunc in senddata failed");
+			ptpip_perror ("getfunc in senddata failed");
 			free (xdata);
 			return PTP_RC_GeneralError;
 		}
@@ -295,11 +285,13 @@ ptp_ptpip_senddata (PTPParams* params, PTPContainer* ptp,
 		GP_LOG_DATA ((char*)xdata, towrite2, "ptpip/senddata data:");
 		written = 0;
 		while (written < towrite2) {
-			ret = PTPSOCK_WRITE (params->cmdfd, xdata+written, towrite2-written);
+			ret = ptpip_write_with_timeout (params->cmdfd, xdata+written, towrite2-written, PTPIP_DEFAULT_TIMEOUT_S, PTPIP_DEFAULT_TIMEOUT_MS);
 			if (ret == PTPSOCK_ERR) {
-				perror ("write in senddata failed");
+				ptpip_perror ("write in senddata failed");
 				free (xdata);
-				return PTP_RC_GeneralError;
+				if (ptpip_get_socket_error() == ETIMEDOUT)
+					return PTP_ERROR_TIMEOUT;
+				return PTP_ERROR_IO;
 			}
 			written += ret;
 		}
@@ -376,6 +368,7 @@ ptp_ptpip_getdata (PTPParams* params, PTPContainer* ptp, PTPDataHandler *handler
 			continue;
 		}
 		GP_LOG_E ("ret type %d", hdr.type);
+		break;
 	}
 	if (curread < toread)
 		return PTP_RC_GeneralError;
@@ -473,13 +466,15 @@ ptp_ptpip_init_command_request (PTPParams* params)
 	htod16a(&cmdrequest[ptpip_initcmd_name+(strlen(hostname)+1)*2+2],PTPIP_VERSION_MAJOR);
 
 	GP_LOG_DATA ((char*)cmdrequest, len, "ptpip/init_cmd data:");
-	ret = PTPSOCK_WRITE (params->cmdfd, cmdrequest, len);
+	ret = ptpip_write_with_timeout (params->cmdfd, cmdrequest, len, PTPIP_DEFAULT_TIMEOUT_S, PTPIP_DEFAULT_TIMEOUT_MS);
 	free (cmdrequest);
 	if (ret == PTPSOCK_ERR) {
-		perror("write init cmd request");
-		return PTP_RC_GeneralError;
+		ptpip_perror("write init cmd request");
+		if (ptpip_get_socket_error() == ETIMEDOUT)
+			return PTP_ERROR_TIMEOUT;
+		return PTP_ERROR_IO;
 	}
-	GP_LOG_E ("return %d / len %d", ret, len);
+	GP_LOG_D ("return %d / len %d", ret, len);
 	if (ret != len) {
 		GP_LOG_E ("return %d vs len %d", ret, len);
 		return PTP_RC_GeneralError;
@@ -534,10 +529,12 @@ ptp_ptpip_init_event_request (PTPParams* params)
 	htod32a(&evtrequest[ptpip_eventinit_idx],params->eventpipeid);
 
 	GP_LOG_DATA ((char*)evtrequest, ptpip_eventinit_size, "ptpip/init_event data:");
-	ret = PTPSOCK_WRITE (params->evtfd, evtrequest, ptpip_eventinit_size);
+	ret = ptpip_write_with_timeout (params->evtfd, evtrequest, ptpip_eventinit_size, PTPIP_DEFAULT_TIMEOUT_S, PTPIP_DEFAULT_TIMEOUT_MS);
 	if (ret == PTPSOCK_ERR) {
-		perror("write init evt request");
-		return PTP_RC_GeneralError;
+		ptpip_perror("write init evt request");
+		if (ptpip_get_socket_error() == ETIMEDOUT)
+			return PTP_ERROR_TIMEOUT;
+		return PTP_ERROR_IO;
 	}
 	if (ret != ptpip_eventinit_size) {
 		GP_LOG_E ("unexpected retsize %d, expected %d", ret, ptpip_eventinit_size);
@@ -597,7 +594,9 @@ ptp_ptpip_event (PTPParams* params, PTPContainer* event, int wait)
 		ret = select (params->evtfd+1, &infds, NULL, NULL, &timeout);
 		if (1 != ret) {
 			if (-1 == ret) {
-				GP_LOG_D ("select returned error, errno is %d", errno);
+				GP_LOG_D ("select returned error, errno is %d", ptpip_get_socket_error());
+				if (ptpip_get_socket_error() == ETIMEDOUT)
+					return PTP_ERROR_TIMEOUT;
 				return PTP_ERROR_IO;
 			}
 			return PTP_ERROR_TIMEOUT;
@@ -765,17 +764,28 @@ ptp_ptpip_connect (PTPParams* params, const char *address) {
 	free (addr);
 	PTPSOCK_SOCKTYPE cmdfd = params->cmdfd = socket (PF_INET, SOCK_STREAM, PTPSOCK_PROTO);
 	if (cmdfd == PTPSOCK_INVALID) {
-		perror ("socket cmd");
+		ptpip_perror ("socket cmd");
 		return GP_ERROR_BAD_PARAMETERS;
 	}
+	if (ptpip_set_nonblock(cmdfd) == -1) {
+		ptpip_perror("cmdfd set nonblocking");
+		PTPSOCK_CLOSE (params->cmdfd);
+		return GP_ERROR_IO;
+	}
 	PTPSOCK_SOCKTYPE evtfd = params->evtfd = socket (PF_INET, SOCK_STREAM, PTPSOCK_PROTO);
 	if (evtfd == PTPSOCK_INVALID) {
-		perror ("socket evt");
+		ptpip_perror ("socket evt");
 		PTPSOCK_CLOSE (params->cmdfd);
 		return GP_ERROR_BAD_PARAMETERS;
 	}
-	if (PTPSOCK_ERR == connect (params->cmdfd, (struct sockaddr*)&saddr, sizeof(struct sockaddr_in))) {
-		perror ("connect cmd");
+	if (ptpip_set_nonblock(evtfd) == -1) {
+		ptpip_perror("evtfd set nonblocking");
+		PTPSOCK_CLOSE (params->cmdfd);
+		PTPSOCK_CLOSE (params->evtfd);
+		return GP_ERROR_IO;
+	}
+	if (ptpip_connect_with_timeout (params->cmdfd, (struct sockaddr*)&saddr, sizeof(struct sockaddr_in), PTPIP_DEFAULT_TIMEOUT_S, PTPIP_DEFAULT_TIMEOUT_MS) == -1) {
+		ptpip_perror("connect cmd");
 		PTPSOCK_CLOSE (params->cmdfd);
 		PTPSOCK_CLOSE (params->evtfd);
 		return GP_ERROR_IO;
@@ -796,9 +806,9 @@ ptp_ptpip_connect (PTPParams* params, const char *address) {
 	tries = 2;
 	saddr.sin_port		= htons(eventport);
 	do {
-		if (PTPSOCK_ERR != connect (params->evtfd, (struct sockaddr*)&saddr, sizeof(struct sockaddr_in)))
+		if (PTPSOCK_ERR != ptpip_connect_with_timeout (params->evtfd, (struct sockaddr*)&saddr, sizeof(struct sockaddr_in), PTPIP_DEFAULT_TIMEOUT_S, PTPIP_DEFAULT_TIMEOUT_MS))
 			break;
-		if ((errno == ECONNREFUSED) && (tries--)) {
+		if ((ptpip_get_socket_error() == ECONNREFUSED) && (tries--)) {
 			GP_LOG_D ("event connect failed, retrying after short wait");
 			int sleep_ms = 100;
 #ifdef WIN32
@@ -822,3 +832,165 @@ ptp_ptpip_connect (PTPParams* params, const char *address) {
 	GP_LOG_D ("ptpip connected!");
 	return GP_OK;
 }
+
+int
+ptp_ptpip_disconnect (PTPParams* params) {
+	if (params->cmdfd != PTPSOCK_INVALID) {
+		PTPSOCK_CLOSE (params->cmdfd);
+		params->cmdfd = PTPSOCK_INVALID;
+	}
+	if (params->evtfd != PTPSOCK_INVALID) {
+		PTPSOCK_CLOSE (params->evtfd);
+		params->evtfd = PTPSOCK_INVALID;
+	}
+	if (params->jpgfd != PTPSOCK_INVALID) {
+		PTPSOCK_CLOSE (params->jpgfd);
+		params->jpgfd = PTPSOCK_INVALID;
+	}
+	GP_LOG_D ("ptpip disconnected!");
+	return GP_OK;
+}
+
+int
+ptpip_connect_with_timeout (int fd, const struct sockaddr *address, socklen_t address_len, int seconds, int milliseconds) {
+	int res = 0;
+	struct timeval tv;
+	socklen_t errsz = sizeof(res);
+	fd_set fds;
+
+	if ((res = connect(fd, address, address_len)) == -1) {
+		if (ptpip_get_socket_error() == EINPROGRESS) { // connection is not ready yet
+			tv.tv_sec = seconds;
+			tv.tv_usec = milliseconds * 1000;
+			FD_ZERO(&fds);
+			FD_SET(fd, &fds);
+			res = select(fd+1, NULL, &fds, NULL, &tv);
+			if (res == -1) { // Select failed
+				ptpip_perror ("select");
+				return -1;
+			} else if (res == 0) { // Timeout
+				ptpip_set_socket_error (ETIMEDOUT);
+				return -1;
+			} else { // Socket is marked as writable, connect is okay, query actual error status
+				if(getsockopt(fd, SOL_SOCKET, SO_ERROR, (char*)&res, &errsz) == -1) {
+					ptpip_perror("getsockopt");
+					return -1;
+				} else if(res != 0) { // Socket has an error
+					ptpip_set_socket_error (res);
+					return -1;
+				} else { // Connect successful
+					return res;
+				}
+			}
+		} else { // connect failed with error.
+			return -1;
+		}
+	}
+	return res;
+}
+
+ssize_t
+ptpip_read_with_timeout (int fd, void *buf, size_t nbytes, int seconds, int milliseconds) {
+	ssize_t res;
+	struct timeval tv;
+	fd_set fds;
+
+	res = PTPSOCK_READ(fd, buf, nbytes);
+	if (res == -1 && (ptpip_get_socket_error() == EAGAIN || ptpip_get_socket_error() == EWOULDBLOCK)) {
+		tv.tv_sec = seconds;
+		tv.tv_usec = milliseconds * 1000;
+		FD_ZERO(&fds);
+		FD_SET(fd, &fds);
+		res = select(fd+1, &fds, NULL, NULL, &tv);
+		if (res == -1) { // Select failed
+			ptpip_perror ("select");
+			return -1;
+		} else if (res == 0) { // Timeout
+			ptpip_set_socket_error (ETIMEDOUT);
+			return -1;
+		} else { // Socket is marked as readable, do the read now
+			return PTPSOCK_READ(fd, buf, nbytes);
+		}
+	} else {
+		return res;
+	}
+}
+
+ssize_t
+ptpip_write_with_timeout (int fd, void *buf, size_t nbytes, int seconds, int milliseconds) {
+	ssize_t res;
+	struct timeval tv;
+	fd_set fds;
+
+	res = PTPSOCK_WRITE(fd, buf, nbytes);
+	if (res == -1 && (ptpip_get_socket_error() == EAGAIN || ptpip_get_socket_error() == EWOULDBLOCK)) {
+		tv.tv_sec = seconds;
+		tv.tv_usec = milliseconds * 1000;
+		FD_ZERO(&fds);
+		FD_SET(fd, &fds);
+		res = select(fd+1, NULL, &fds, NULL, &tv);
+		if (res == -1) { // Select failed
+			ptpip_perror ("select");
+			return -1;
+		} else if (res == 0) { // Timeout
+			ptpip_set_socket_error (ETIMEDOUT);
+			return -1;
+		} else { // Socket is marked as writable, do the write now
+			return PTPSOCK_WRITE(fd, buf, nbytes);
+		}
+	} else {
+		return res;
+	}
+}
+
+int
+ptpip_set_nonblock (int fd) {
+#ifdef WIN32
+	u_long mode = 0;
+	if (ioctlsocket (fd, FIONBIO, &mode) == SOCKET_ERROR) {
+		return -1;
+	}
+#else
+	int flags = fcntl(fd, F_GETFL);
+	if (flags < 0) {
+		return -1;
+	}
+	if (fcntl(fd, F_SETFL, flags | O_NONBLOCK) < 0) {
+		return -1;
+	}
+#endif
+	return 0;
+}
+
+void
+ptpip_perror (const char *what) {
+#ifdef WIN32
+	wchar_t *s = NULL;
+	FormatMessageW (FORMAT_MESSAGE_ALLOCATE_BUFFER | FORMAT_MESSAGE_FROM_SYSTEM | FORMAT_MESSAGE_IGNORE_INSERTS,
+		NULL, WSAGetLastError(),
+		MAKELANGID(LANG_NEUTRAL, SUBLANG_NEUTRAL),
+		(LPWSTR)&s, 0, NULL);
+	fprintf(stderr, "%s: %S\n", what, s);
+	fflush(stderr);
+	LocalFree(s);
+#else
+	perror(what);
+#endif
+}
+
+int
+ptpip_get_socket_error (void) {
+#ifdef WIN32
+	return WSAGetLastError();
+#else
+	return errno;
+#endif
+}
+
+void
+ptpip_set_socket_error (int err) {
+#ifdef WIN32
+	WSASetLastError(err);
+#endif
+	errno = err;
+}
