@@ -26,33 +26,17 @@
 #include <ctype.h>
 #include <string.h>
 #include <time.h>
+#include <unistd.h>
 
 #include <gphoto2/gphoto2-port-log.h>
 
+#include "libgphoto2/i18n.h"
+
 #include "sierra.h"
 #include "sierra-usbwrap.h"
 
 #define GP_MODULE "sierra"
 
-#ifdef ENABLE_NLS
-#  include <libintl.h>
-#  undef _
-#  define _(String) dgettext (GETTEXT_PACKAGE, String)
-#  ifdef gettext_noop
-#    define N_(String) gettext_noop (String)
-#  else
-#    define N_(String) (String)
-#  endif
-#else
-#  define textdomain(String) (String)
-#  define gettext(String) (String)
-#  define dgettext(Domain,Message) (Message)
-#  define dcgettext(Domain,Message,Type) (Message)
-#  define bindtextdomain(Domain,Directory) (Domain)
-#  define _(String) (String)
-#  define N_(String) (String)
-#endif
-
 enum _SierraPacket {
 	NUL				= 0x00,
 	SIERRA_PACKET_DATA		= 0x02,
@@ -61,6 +45,7 @@ enum _SierraPacket {
 	ACK				= 0x06,
 	SIERRA_PACKET_INVALID		= 0x11,
 	SIERRA_PACKET_NAK		= 0x15,
+	SIERRA_PACKET_CANCEL		= 0x18,
 	SIERRA_PACKET_COMMAND		= 0x1b,
 	SIERRA_PACKET_WRONG_SPEED	= 0x8c,
 	SIERRA_PACKET_SESSION_ERROR	= 0xfc,
@@ -460,7 +445,12 @@ sierra_write_packet (Camera *camera, char *packet, GPContext *context)
 			(camera->pl->flags & SIERRA_WRAP_USB_MASK),
 			packet, length));
 	} else {
-		CHECK (gp_port_write (camera->port, packet, length));
+		if (camera->pl->flags & SIERRA_NO_BLOCK_WRITE) {
+			for (x = 0; x < length; x++)
+				CHECK (gp_port_write(camera->port, &packet[x], 1));
+		} else {
+			CHECK (gp_port_write (camera->port, packet, length));
+		}
 	}
 
 	return GP_OK;
@@ -469,26 +459,25 @@ sierra_write_packet (Camera *camera, char *packet, GPContext *context)
 static int
 sierra_clear_usb_halt(Camera *camera)
 {
-
-	if ( (camera->port->type == GP_PORT_USB) &&
-	     !(camera->pl->flags & SIERRA_WRAP_USB_MASK) &&
-	     !(camera->pl->flags & SIERRA_NO_USB_CLEAR) )
+	if ((camera->port->type == GP_PORT_USB) &&
+		!(camera->pl->flags & SIERRA_WRAP_USB_MASK) &&
+		!(camera->pl->flags & SIERRA_NO_USB_CLEAR))
 		gp_port_usb_clear_halt(camera->port, GP_PORT_USB_ENDPOINT_IN);
-        return (GP_OK);
+	return (GP_OK);
 }
 
 static int
 sierra_write_nak (Camera *camera, GPContext *context)
 {
-        char buf[4096];
-        int ret;
+	char buf[4096];
+	int ret;
 
-        GP_DEBUG ("* sierra_write_nack");
+	GP_DEBUG ("* sierra_write_nack");
 
-        buf[0] = SIERRA_PACKET_NAK;
-        ret = sierra_write_packet (camera, buf, context);
+	buf[0] = SIERRA_PACKET_NAK;
+	ret = sierra_write_packet (camera, buf, context);
 	sierra_clear_usb_halt(camera);
-        return (ret);
+	return (ret);
 }
 
 /**
@@ -591,6 +580,7 @@ sierra_read_packet (Camera *camera, unsigned char *packet, GPContext *context)
 		case ACK:
 		case SIERRA_PACKET_INVALID:
 		case SIERRA_PACKET_NAK:
+		case SIERRA_PACKET_CANCEL:
 		case SIERRA_PACKET_SESSION_ERROR:
 		case SIERRA_PACKET_SESSION_END:
 		case SIERRA_PACKET_WRONG_SPEED:
@@ -790,6 +780,7 @@ sierra_transmit_ack (Camera *camera, char *packet, GPContext *context)
 			GP_DEBUG ("Transmission successful.");
 			return GP_OK;
 		case SIERRA_PACKET_INVALID:
+		case SIERRA_PACKET_CANCEL:
 			gp_context_error (context, _("Packet was rejected "
 				"by camera. Please contact "
 				"%s."), MAIL_GPHOTO_DEVEL);
@@ -806,10 +797,10 @@ sierra_transmit_ack (Camera *camera, char *packet, GPContext *context)
 			}
 
 			/*
-                         * The camera has ended this session and
-                         * reverted the speed back to 19200. Reinitialize
+			 * The camera has ended this session and
+			 * reverted the speed back to 19200. Reinitialize
 			 * the connection.
-                         */
+			 */
 			CHECK (sierra_init (camera, context));
 			CHECK (sierra_set_speed (camera, SIERRA_SPEED_19200,
 						 context));
@@ -939,15 +930,15 @@ sierra_init (Camera *camera, GPContext *context)
 }
 
 static struct {
-        SierraSpeed speed;
-        int bit_rate;
+	SierraSpeed speed;
+	int bit_rate;
 } SierraSpeeds[] = {
-        {SIERRA_SPEED_9600  ,   9600},
-        {SIERRA_SPEED_19200 ,  19200},
-        {SIERRA_SPEED_38400 ,  38400},
-        {SIERRA_SPEED_57600 ,  57600},
-        {SIERRA_SPEED_115200, 115200},
-        {0, 0}
+	{SIERRA_SPEED_9600  ,   9600},
+	{SIERRA_SPEED_19200 ,  19200},
+	{SIERRA_SPEED_38400 ,  38400},
+	{SIERRA_SPEED_57600 ,  57600},
+	{SIERRA_SPEED_115200, 115200},
+	{0, 0}
 };
 
 int
@@ -1212,7 +1203,7 @@ sierra_set_string_register (Camera *camera, int reg, const char *s,
 }
 
 int sierra_get_string_register (Camera *camera, int reg, int fnumber,
-                                CameraFile *file, unsigned char *b,
+				CameraFile *file, unsigned char *b,
 				unsigned int *b_len, GPContext *context)
 {
 	unsigned char p[34816];
@@ -1299,9 +1290,9 @@ int sierra_get_string_register (Camera *camera, int reg, int fnumber,
 		*b_len += packlength;
 
 		if (file) {
-		    CHECK (gp_file_append (file, (char *)&p[4], packlength));
-		    if (total > min_progress_bytes)
-			gp_context_progress_update (context, id, *b_len);
+			CHECK (gp_file_append (file, (char *)&p[4], packlength));
+			if (total > min_progress_bytes)
+				gp_context_progress_update (context, id, *b_len);
 		}
 
 	} while (p[0] != SIERRA_PACKET_DATA_END);
