@@ -1,23 +1,27 @@
 var dir_df723b3f25cfe80b0e773fc78a5873a4 =
 [
+    [ "_stdint.h", "__stdint_8h_source.html", null ],
     [ "ahd_bayer.c", "ahd__bayer_8c.html", "ahd__bayer_8c" ],
+    [ "bayer-types.h", "bayer-types_8h.html", "bayer-types_8h" ],
     [ "bayer.c", "bayer_8c.html", "bayer_8c" ],
     [ "bayer.h", "bayer_8h.html", "bayer_8h" ],
-    [ "exif.c", "exif_8c.html", "exif_8c" ],
-    [ "exif.h", "exif_8h.html", "exif_8h" ],
+    [ "exif.c", "exif_8c.html", null ],
+    [ "exif.h", "exif_8h.html", null ],
     [ "gamma.c", "gamma_8c.html", "gamma_8c" ],
     [ "gamma.h", "gamma_8h.html", "gamma_8h" ],
     [ "gphoto2-abilities-list.c", "gphoto2-abilities-list_8c.html", "gphoto2-abilities-list_8c" ],
     [ "gphoto2-camera.c", "gphoto2-camera_8c.html", "gphoto2-camera_8c" ],
     [ "gphoto2-context.c", "gphoto2-context_8c.html", "gphoto2-context_8c" ],
+    [ "gphoto2-endian.h", "gphoto2-endian_8h_source.html", null ],
     [ "gphoto2-file.c", "gphoto2-file_8c.html", "gphoto2-file_8c" ],
     [ "gphoto2-filesys.c", "gphoto2-filesys_8c.html", "gphoto2-filesys_8c" ],
     [ "gphoto2-library.c", "gphoto2-library_8c.html", "gphoto2-library_8c" ],
     [ "gphoto2-list.c", "gphoto2-list_8c.html", "gphoto2-list_8c" ],
     [ "gphoto2-result.c", "gphoto2-result_8c.html", "gphoto2-result_8c" ],
     [ "gphoto2-setting.c", "gphoto2-setting_8c.html", "gphoto2-setting_8c" ],
-    [ "gphoto2-version.c", "gphoto2-version_8c.html", "gphoto2-version_8c" ],
+    [ "gphoto2-version.c", "gphoto2-version_8c.html", null ],
     [ "gphoto2-widget.c", "gphoto2-widget_8c.html", "gphoto2-widget_8c" ],
-    [ "jpeg.c", "jpeg_8c.html", "jpeg_8c" ],
+    [ "i18n.h", "libgphoto2_2i18n_8h.html", null ],
+    [ "jpeg.c", "jpeg_8c.html", null ],
     [ "jpeg.h", "jpeg_8h.html", "jpeg_8h" ]
 ];
\ No newline at end of file
