@@ -2,9 +2,10 @@ var dir_ff2570e7e5c377838c8e56ea8c3b24f7 =
 [
     [ "gphoto2-port-info-list.h", "gphoto2-port-info-list_8h.html", "gphoto2-port-info-list_8h" ],
     [ "gphoto2-port-library.h", "gphoto2-port-library_8h.html", "gphoto2-port-library_8h" ],
+    [ "gphoto2-port-locking.h", "gphoto2-port-locking_8h.html", null ],
     [ "gphoto2-port-log.h", "gphoto2-port-log_8h.html", "gphoto2-port-log_8h" ],
-    [ "gphoto2-port-portability.h", "gphoto2-port-portability_8h.html", null ],
+    [ "gphoto2-port-portability.h", "gphoto2-port-portability_8h_source.html", null ],
     [ "gphoto2-port-result.h", "gphoto2-port-result_8h.html", "gphoto2-port-result_8h" ],
-    [ "gphoto2-port-version.h", "gphoto2-port-version_8h.html", "gphoto2-port-version_8h" ],
+    [ "gphoto2-port-version.h", "gphoto2-port-version_8h.html", null ],
     [ "gphoto2-port.h", "gphoto2-port_8h.html", "gphoto2-port_8h" ]
 ];
\ No newline at end of file
