@@ -10,8 +10,8 @@
  *
  */
 
-static void errordumper(GPLogLevel level, const char *domain, const char *str,
-                 void *data) {
+static void errordumper(GPLogLevel level, const char *domain, const char *str, void *data)
+{
 	/* Do not log ... but let it appear here so we discover debug paths */
 	fprintf(stderr, "%s:%s\n", domain, str);
 }
@@ -47,11 +47,7 @@ recursive_directory(Camera *camera, const char *folder, GPContext *context, int
 
 		if (!strlen(newfolder)) continue;
 
-		buf = malloc (strlen(folder) + 1 + strlen(newfolder) + 1);
-		strcpy(buf, folder);
-		if (strcmp(folder,"/"))		/* avoid double / */
-			strcat(buf, "/");
-		strcat(buf, newfolder);
+		buf = aprintf("%s%s%s", folder, strcmp(folder, "/") ? "/" : "", newfolder);
 
 		fprintf(stderr,"newfolder=%s\n", newfolder);
 
@@ -145,7 +141,7 @@ int main(int argc, char **argv) {
 	CameraAbilitiesList      *abilities = NULL;
 
 
-        gp_log_add_func(GP_LOG_DEBUG, errordumper, NULL);
+	gp_log_add_func(GP_LOG_DEBUG, errordumper, NULL);
 
 	context = sample_create_context (); /* see context.c */
 
@@ -162,9 +158,9 @@ int main(int argc, char **argv) {
 	ret = gp_port_info_list_lookup_path (gpinfolist, buf);
 	if (ret < GP_OK) return ret;
 
-        /* Detect all the cameras that can be autodetected... */
-        ret = gp_list_new (&list);
-        if (ret < GP_OK) return 1;
+	/* Detect all the cameras that can be autodetected... */
+	ret = gp_list_new (&list);
+	if (ret < GP_OK) return 1;
 
 	/* Load all the camera drivers we have... */
 	ret = gp_abilities_list_new (&abilities);
@@ -185,7 +181,7 @@ int main(int argc, char **argv) {
 	fprintf(stderr, "name is %s\n", name);
 
 	ret = sample_open_camera (&camera, name, buf, context);
-        if (ret < GP_OK) {
+	if (ret < GP_OK) {
 		fprintf(stderr,"camera %s at %s not found.\n", name, buf);
 		gp_list_free (list);
 		goto out;
@@ -241,7 +237,7 @@ int main(int argc, char **argv) {
 
 		ret = gp_camera_wait_for_event(camera, 1, &evttype, &data, context);
 		if (ret < GP_OK) break;
-		if (data) free (data);
+		free (data);
 		if (evttype == GP_EVENT_TIMEOUT) break;
 	}
 
@@ -255,7 +251,7 @@ int main(int argc, char **argv) {
 	gp_file_free (file);
 
 #if 0
-	/* this gives endless event check loops occasionaly ... need review how to do this best */
+	/* this gives endless event check loops occasionally ... need review how to do this best */
 	ret = gp_camera_capture (camera, GP_CAPTURE_IMAGE, &path, context);
 	if ((ret != GP_OK) && (ret != GP_ERROR_NOT_SUPPORTED)) {
 		printf ("Could not capture preview.\n");
