@@ -179,8 +179,13 @@ foreach_func (const char *filename, lt_ptr data)
 {
 	foreach_data_t *fd = data;
 	CameraList *list = fd->list;
+	char *prefix = getenv(CAMLIBDIR_PREFIX_ENV);
 
 	GP_LOG_D ("Found '%s'.", filename);
+	if(prefix && !strstr(filename,prefix)) {
+		GP_LOG_D("Skipping camlib filename '%s' not matching %s.",filename,prefix);
+		return (0);
+	}
 	fd->result = gp_list_append (list, filename, NULL);
 
 	return ((fd->result == GP_OK)?0:1);
@@ -312,6 +317,7 @@ unlocked_gp_abilities_list_load_dir (CameraAbilitiesList *list, const char *dir,
 			return GP_ERROR_CANCEL;
 		}
 	}
+
 	gp_context_progress_stop (context, p);
 	lt_dlexit ();
 	gp_list_free (flist);
@@ -557,9 +563,9 @@ gp_abilities_list_append (CameraAbilitiesList *list, CameraAbilities abilities)
 	C_PARAMS (list);
 
 	if (list->count == list->maxcount) {
-	    C_MEM (list->abilities = realloc (list->abilities,
+		C_MEM (list->abilities = realloc (list->abilities,
 				sizeof (CameraAbilities) * (list->maxcount + 100)));
-	    list->maxcount += 100;
+		list->maxcount += 100;
 	}
 
 	memcpy (&(list->abilities [list->count]), &abilities,
