@@ -42,24 +42,8 @@
 #  include <libexif/exif-data.h>
 #endif
 
-#ifdef ENABLE_NLS
-#  include <libintl.h>
-#  undef _
-#  define _(String) dgettext (GETTEXT_PACKAGE, String)
-#  ifdef gettext_noop
-#    define N_(String) gettext_noop (String)
-#  else
-#    define N_(String) (String)
-#  endif
-#else
-#  define textdomain(String) (String)
-#  define gettext(String) (String)
-#  define dgettext(Domain,Message) (Message)
-#  define dcgettext(Domain,Message,Type) (Message)
-#  define bindtextdomain(Domain,Directory) (Domain)
-#  define _(String) (String)
-#  define N_(String) (String)
-#endif
+#include "libgphoto2/i18n.h"
+
 
 #ifndef PATH_MAX
 # define PATH_MAX 4096
@@ -446,7 +430,7 @@ lookup_folder_file (
 		CameraList	*list;
 		int		ret;
 		/*
-                 * The folder is dirty. List the files in it to make it clean.
+		 * The folder is dirty. List the files in it to make it clean.
 		 */
 		GP_LOG_D ("Folder %s is dirty. "
 			"Listing files in there to make folder clean...", folder);
@@ -662,7 +646,7 @@ gp_filesystem_new (CameraFilesystem **fs)
 
 	C_MEM (*fs = calloc (1, sizeof (CameraFilesystem)));
 
-	(*fs)->rootfolder = calloc (sizeof (CameraFilesystemFolder), 1);
+	(*fs)->rootfolder = calloc (1, sizeof (CameraFilesystemFolder));
 	if (!(*fs)->rootfolder) {
 		free (*fs);
 		return (GP_ERROR_NO_MEMORY);
@@ -732,7 +716,7 @@ internal_append (CameraFilesystem *fs, CameraFilesystemFolder *f,
 	if (*new)
 		return (GP_ERROR_FILE_EXISTS);
 
-	C_MEM ((*new) = calloc (sizeof (CameraFilesystemFile), 1));
+	C_MEM ((*new) = calloc (1, sizeof (CameraFilesystemFile)));
 	(*new)->name = strdup (filename);
 	if (!(*new)->name) {
 		free (*new);
@@ -763,11 +747,10 @@ gp_filesystem_append (CameraFilesystem *fs, const char *folder,
 		CameraList	*xlist;
 		int ret;
 
-		ret = gp_list_new (&xlist);
-		if (ret != GP_OK) return ret;
+		CR (gp_list_new (&xlist));
 		ret = gp_filesystem_list_files (fs, folder, xlist, context);
 		gp_list_free (xlist);
-		if (ret != GP_OK) return ret;
+		CR (ret);
 	}
 	ret = internal_append (fs, f, filename, context);
 	if (ret == GP_ERROR_FILE_EXISTS) /* not an error here ... just in case we add files twice to the list */
@@ -983,7 +966,6 @@ gp_filesystem_list_files (CameraFilesystem *fs, const char *folder,
 		CR (count = gp_list_count (list));
 		for (y = 0; y < count; y++) {
 			CR (gp_list_get_name (list, y, &name));
-			GP_LOG_D ("Added '%s'", name);
 			CR (internal_append (fs, f, name, context));
 		}
 		gp_list_reset (list);
@@ -993,8 +975,7 @@ gp_filesystem_list_files (CameraFilesystem *fs, const char *folder,
 
 	file = f->files;
 	while (file) {
-		GP_LOG_D (
-			"Listed '%s'", file->name);
+		/* GP_LOG_D ("Listed '%s'", file->name); */
 		CR (gp_list_append (list, file->name, NULL));
 		file = file->next;
 	}
@@ -1142,7 +1123,7 @@ gp_filesystem_delete_file (CameraFilesystem *fs, const char *folder,
 }
 
 /**
- * \brief Delete a virtal file from a folder in the filesystem
+ * \brief Delete a virtual file from a folder in the filesystem
  * \param fs a #CameraFilesystem
  * \param folder a folder in which to delete the file
  * \param filename the name of the file to delete
@@ -1481,16 +1462,13 @@ recursive_folder_scan (
 		char *xfolder;
 		ret = recursive_folder_scan (f, lookforfile, &xfolder);
 		if (ret == GP_OK) {
-			C_MEM ((*foldername) = malloc (strlen (folder->name) + 1 + strlen (xfolder) + 1));
-			strcpy ((*foldername),folder->name);
-			strcat ((*foldername),"/");
-			strcat ((*foldername),xfolder);
+			*foldername = aprintf("%s/%s", folder->name, xfolder);
 			free (xfolder);
 			return GP_OK;
 		}
 		f = f->next;
 	}
-	/* thorugh all subfoilders */
+	/* through all subfolders */
 	return GP_ERROR_FILE_NOT_FOUND;
 }
 /**
@@ -1771,9 +1749,6 @@ gp_filesystem_read_file (CameraFilesystem *fs, const char *folder,
 			GPContext *context)
 {
 	int r;
-	const char	*xdata;
-	unsigned long	xsize;
-	CameraFile	*file;
 
 	C_PARAMS (fs && folder && filename && buf && size);
 	CC (context);
@@ -1788,7 +1763,13 @@ gp_filesystem_read_file (CameraFilesystem *fs, const char *folder,
 		return GP_ERROR_NOT_SUPPORTED;
 	}
 	return r;
+
+#if 0
 	/* fallback code */
+	const char	*xdata;
+	unsigned long	xsize;
+	CameraFile	*file;
+
 	CR (gp_file_new (&file));
 	CR (gp_filesystem_get_file (fs, folder, filename, type,
 				    file, context));
@@ -1809,6 +1790,7 @@ gp_filesystem_read_file (CameraFilesystem *fs, const char *folder,
 	memcpy (buf, xdata+offset, *size);
 	gp_file_unref (file);
 	return GP_OK;
+#endif
 }
 /**
  * \brief Set all filesystem related function pointers
@@ -2352,6 +2334,37 @@ gp_filesystem_set_info_noop (CameraFilesystem *fs,
 	return (GP_OK);
 }
 
+/**
+ * \brief Mark the file info as dirty
+ * \param fs a #CameraFilesystem
+ * \param folder the foldername
+ * \param filename the filename
+ * \param context a #GPContext
+ *
+ * Mark the file info as dirty, so that the next attempt
+ * to retrieve the file info will query the camera driver
+ * instead of possibly returning cached data.
+ *
+ * \return a gphoto2 error code
+ **/
+int gp_filesystem_set_info_dirty    (CameraFilesystem *fs,
+				    const char *folder, const char *filename,
+				    GPContext *context)
+{
+	CameraFilesystemFolder	*f;
+	CameraFilesystemFile	*xfile;
+
+	C_PARAMS (fs && folder);
+	CC (context);
+	CA (folder, context);
+
+	/* Search folder and file */
+	CR (lookup_folder_file (fs, folder, filename, &f, &xfile, context));
+
+	xfile->info_dirty = 1;
+	return (GP_OK);
+}
+
 /**
  * \brief Set information about a file
  * \param fs a #CameraFilesystem
