@@ -62,7 +62,6 @@ extern "C" {
 
 #ifdef _GPHOTO2_INTERNAL_CODE
 #include <gphoto2/gphoto2-port-log.h>
-extern const StringFlagItem gpi_gphoto_port_type_map[];
 #endif
 
 int gp_port_info_new (GPPortInfo *info);
@@ -94,6 +93,9 @@ int gp_port_info_list_get_info (GPPortInfoList *list, int n, GPPortInfo *info);
 
 const char *gp_port_message_codeset (const char*);
 
+int gp_port_init_localedir (const char *localedir);
+
+
 /**
  * Name of the environment variable which may contain the path where
  * to look for the IO libs. If this environment variable is not defined,
@@ -103,6 +105,7 @@ const char *gp_port_message_codeset (const char*);
  */
 #ifdef _GPHOTO2_INTERNAL_CODE
 #define IOLIBDIR_ENV "IOLIBS"
+#define IOLIBDIR_PREFIX_ENV "IOLIBS_PREFIX"
 #endif /* _GPHOTO2_INTERNAL_CODE */
 
 
