@@ -224,7 +224,7 @@ gp_port_info_list_append (GPPortInfoList *list, GPPortInfo info)
 	for (generic = i = 0; i < list->count; i++)
 		if (!strlen (list->info[i]->name))
 			generic++;
-        return (list->count - 1 - generic);
+	return (list->count - 1 - generic);
 }
 
 
@@ -238,8 +238,13 @@ foreach_func (const char *filename, lt_ptr data)
 	GPPortType type;
 	unsigned int j, old_size = list->count;
 	int result;
+	char *prefix = getenv(IOLIBDIR_PREFIX_ENV);
 
 	GP_LOG_D ("Called for filename '%s'.", filename );
+	if(prefix && !strstr(filename,prefix)) {
+		GP_LOG_D("Skipping filename '%s' not matching %s.",filename,prefix);
+		return (0);
+	}
 
 	lh = lt_dlopenext (filename);
 	if (!lh) {
@@ -328,7 +333,7 @@ gp_port_info_list_load (GPPortInfoList *list)
 		GP_LOG_E ("No iolibs found in '%s'", iolibs);
 		return GP_ERROR_LIBRARY;
 	}
-        return (GP_OK);
+	return (GP_OK);
 }
 
 /**
@@ -522,7 +527,7 @@ gp_port_info_list_get_info (GPPortInfoList *list, int n, GPPortInfo *info)
  * \param info a #GPPortInfo
  * \param name a pointer to a char* which will receive the name
  *
- * Retreives the name of the passed in GPPortInfo, by reference.
+ * Retrieves the name of the passed in GPPortInfo, by reference.
  *
  * \return a gphoto2 error code
  **/
@@ -553,7 +558,7 @@ gp_port_info_set_name (GPPortInfo info, const char *name) {
  * \param info a #GPPortInfo
  * \param path a pointer to a char* which will receive the path
  *
- * Retreives the path of the passed in GPPortInfo, by reference.
+ * Retrieves the path of the passed in GPPortInfo, by reference.
  *
  * \return a gphoto2 error code
  **/
@@ -584,7 +589,7 @@ gp_port_info_set_path (GPPortInfo info, const char *path) {
  * \param info a #GPPortInfo
  * \param type a pointer to a GPPortType variable which will receive the type
  *
- * Retreives the type of the passed in GPPortInfo
+ * Retrieves the type of the passed in GPPortInfo
  *
  * \return a gphoto2 error code
  **/
