@@ -1,5 +1,7 @@
 var NAVTREEINDEX1 =
 {
+"gphoto2-endian_8h_source.html":[3,0,2,12],
+"gphoto2-file_8c.html":[3,0,2,13],
 "gphoto2-file_8c.html#a0376d5d1c7af0edde33cdbe7f3d2eb1e":[3,0,2,13,13],
 "gphoto2-file_8c.html#a4415b2867b1a8d6c032018db99fd3fee":[3,0,2,13,8],
 "gphoto2-file_8c.html#a53f5f6a8338c9889645b658be2d9e5c4":[3,0,2,13,22],
@@ -207,6 +209,7 @@ var NAVTREEINDEX1 =
 "gphoto2-list_8h.html#af6e936a6ccc3fe258d0c90b95c8ea8a2":[3,0,1,6,5],
 "gphoto2-list_8h_source.html":[3,0,1,6],
 "gphoto2-port-info-list_8c.html":[3,0,3,1,1],
+"gphoto2-port-info-list_8c.html#a165a0da49a5445bf3b0cb3a98b482455":[3,0,3,1,1,16],
 "gphoto2-port-info-list_8c.html#a2784f52a6cddb255967a1400e0e07a9a":[3,0,3,1,1,13],
 "gphoto2-port-info-list_8c.html#a29c6f449ee68a718c6c31b1f10202fda":[3,0,3,1,1,5],
 "gphoto2-port-info-list_8c.html#a311d69766c99ba691b0d8f7bfb725d8a":[3,0,3,1,1,11],
@@ -220,7 +223,7 @@ var NAVTREEINDEX1 =
 "gphoto2-port-info-list_8c.html#a9810bfba9c986f4d102cfaf649199f21":[3,0,3,1,1,1],
 "gphoto2-port-info-list_8c.html#aa3084e7f2920c7917d71ae0abd8b7a64":[3,0,3,1,1,15],
 "gphoto2-port-info-list_8c.html#ab60c983825bfa2b6aa2fcb1e1a32b08f":[3,0,3,1,1,6],
-"gphoto2-port-info-list_8c.html#ac8dff5fad860125bc0ab0d4bde53c77d":[3,0,3,1,1,16],
+"gphoto2-port-info-list_8c.html#ac8dff5fad860125bc0ab0d4bde53c77d":[3,0,3,1,1,17],
 "gphoto2-port-info-list_8c.html#acbb59be40d7a67a13b7ffd26dcd3e9bb":[3,0,3,1,1,4],
 "gphoto2-port-info-list_8c.html#ad925c660b558db82d22c62e8ae09c756":[3,0,3,1,1,10],
 "gphoto2-port-info-list_8h.html":[3,0,3,0,0],
@@ -233,21 +236,18 @@ var NAVTREEINDEX1 =
 "gphoto2-port-info-list_8h.html#a0607050fab17d2a8c0cbff5747aadc06ad617621b30d81296d06c2a31a3e5d13a":[3,0,3,0,0,0,5],
 "gphoto2-port-info-list_8h.html#a0607050fab17d2a8c0cbff5747aadc06add04533b323ad226aadbb648394308c8":[3,0,3,0,0,0,2],
 "gphoto2-port-info-list_8h.html#a0607050fab17d2a8c0cbff5747aadc06aebfd6b4f7f72955e68a546eab8d6b081":[3,0,3,0,0,0,1],
+"gphoto2-port-info-list_8h.html#a165a0da49a5445bf3b0cb3a98b482455":[3,0,3,0,0,16],
 "gphoto2-port-info-list_8h.html#a2784f52a6cddb255967a1400e0e07a9a":[3,0,3,0,0,13],
 "gphoto2-port-info-list_8h.html#a292ba5489b58951ccb1c858afe2f2798":[3,0,3,0,0,15],
 "gphoto2-port-info-list_8h.html#a29c6f449ee68a718c6c31b1f10202fda":[3,0,3,0,0,5],
 "gphoto2-port-info-list_8h.html#a311d69766c99ba691b0d8f7bfb725d8a":[3,0,3,0,0,11],
 "gphoto2-port-info-list_8h.html#a45fd0887ac55832030f5f063d828c135":[3,0,3,0,0,9],
 "gphoto2-port-info-list_8h.html#a4621674c74440cc4d68d24e45fc9f148":[3,0,3,0,0,14],
-"gphoto2-port-info-list_8h.html#a50b6aadf6f944f92dd084933170498ea":[3,0,3,0,0,16],
+"gphoto2-port-info-list_8h.html#a50b6aadf6f944f92dd084933170498ea":[3,0,3,0,0,17],
 "gphoto2-port-info-list_8h.html#a61b08d6eddea3c0e0c51869363632cea":[3,0,3,0,0,8],
 "gphoto2-port-info-list_8h.html#a70f65ef80a59174adfa52c3e199752d4":[3,0,3,0,0,3],
 "gphoto2-port-info-list_8h.html#a85b97ad361854a8076b61be70fe85304":[3,0,3,0,0,7],
 "gphoto2-port-info-list_8h.html#a8677c876b22dc6b4545e92fda9810ed4":[3,0,3,0,0,12],
 "gphoto2-port-info-list_8h.html#a9736997967ed0bdb2ac0ace4e02df531":[3,0,3,0,0,2],
-"gphoto2-port-info-list_8h.html#a9810bfba9c986f4d102cfaf649199f21":[3,0,3,0,0,1],
-"gphoto2-port-info-list_8h.html#ab60c983825bfa2b6aa2fcb1e1a32b08f":[3,0,3,0,0,6],
-"gphoto2-port-info-list_8h.html#acbb59be40d7a67a13b7ffd26dcd3e9bb":[3,0,3,0,0,4],
-"gphoto2-port-info-list_8h.html#ad925c660b558db82d22c62e8ae09c756":[3,0,3,0,0,10],
-"gphoto2-port-info-list_8h_source.html":[3,0,3,0,0]
+"gphoto2-port-info-list_8h.html#a9810bfba9c986f4d102cfaf649199f21":[3,0,3,0,0,1]
 };
