@@ -22,7 +22,7 @@ static
 unsigned long stdc_version = __STDC_VERSION__;
 #endif
 
-int main()
+int main(void)
 {
 #ifdef __STDC_VERSION__
   printf("stdc_version = %lu\n", stdc_version);
